@@ -1,7 +1,7 @@
 """
 Type annotations for cloudwatch service ServiceResource
 
-[Open documentation](./service_resource.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
 
 Usage::
 
@@ -60,8 +60,8 @@ __all__ = (
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
-    [Show boto3-stubs documentation](./service_resource.md#serviceresourcealarmscollection)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcealarmscollection)
     """
 
     def all(self) -> "ServiceResourceAlarmsCollection":
@@ -69,6 +69,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
 
     def filter(  # type: ignore
         self,
+        *,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
         AlarmTypes: List[AlarmTypeType] = None,
@@ -77,7 +78,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
         StateValue: StateValueType = None,
         ActionPrefix: str = None,
         MaxRecords: int = None,
-        NextToken: str = None,
+        NextToken: str = None
     ) -> "ServiceResourceAlarmsCollection":
         pass
 
@@ -105,8 +106,8 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
-    [Show boto3-stubs documentation](./service_resource.md#serviceresourcemetricscollection)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcemetricscollection)
     """
 
     def all(self) -> "ServiceResourceMetricsCollection":
@@ -114,11 +115,12 @@ class ServiceResourceMetricsCollection(ResourceCollection):
 
     def filter(  # type: ignore
         self,
+        *,
         Namespace: str = None,
         MetricName: str = None,
         Dimensions: List[DimensionFilterTypeDef] = None,
         NextToken: str = None,
-        RecentlyActive: Literal["PT3H"] = None,
+        RecentlyActive: Literal["PT3H"] = None
     ) -> "ServiceResourceMetricsCollection":
         pass
 
@@ -137,8 +139,8 @@ class ServiceResourceMetricsCollection(ResourceCollection):
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
-    [Show boto3-stubs documentation](./service_resource.md#metricalarmscollection)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricalarmscollection)
     """
 
     def all(self) -> "MetricAlarmsCollection":
@@ -146,11 +148,12 @@ class MetricAlarmsCollection(ResourceCollection):
 
     def filter(  # type: ignore
         self,
+        *,
         Statistic: StatisticType = None,
         ExtendedStatistic: str = None,
         Dimensions: List["DimensionTypeDef"] = None,
         Period: int = None,
-        Unit: StandardUnitType = None,
+        Unit: StandardUnitType = None
     ) -> "MetricAlarmsCollection":
         pass
 
@@ -178,7 +181,7 @@ class MetricAlarmsCollection(ResourceCollection):
 
 class Alarm(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)[Show boto3-stubs documentation](./service_resource.md#alarm)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarm)
     """
 
     alarm_name: str
@@ -213,61 +216,62 @@ class Alarm(Boto3ServiceResource):
 
     def delete(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
-        [Show boto3-stubs documentation](./service_resource.md#alarmdeletemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdelete-method)
         """
 
     def describe_history(
         self,
+        *,
         AlarmTypes: List[AlarmTypeType] = None,
         HistoryItemType: HistoryItemTypeType = None,
         StartDate: datetime = None,
         EndDate: datetime = None,
         MaxRecords: int = None,
         NextToken: str = None,
-        ScanBy: ScanByType = None,
+        ScanBy: ScanByType = None
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
-        [Show boto3-stubs documentation](./service_resource.md#alarmdescribe_historymethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdescribe_history-method)
         """
 
     def disable_actions(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
-        [Show boto3-stubs documentation](./service_resource.md#alarmdisable_actionsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdisable_actions-method)
         """
 
     def enable_actions(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
-        [Show boto3-stubs documentation](./service_resource.md#alarmenable_actionsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmenable_actions-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#alarmget_available_subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmget_available_subresources-method)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
-        [Show boto3-stubs documentation](./service_resource.md#alarmloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmload-method)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
-        [Show boto3-stubs documentation](./service_resource.md#alarmreloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmreload-method)
         """
 
     def set_state(
-        self, StateValue: StateValueType, StateReason: str, StateReasonData: str = None
+        self, *, StateValue: StateValueType, StateReason: str, StateReasonData: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
-        [Show boto3-stubs documentation](./service_resource.md#alarmset_statemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmset_state-method)
         """
 
 
@@ -276,7 +280,7 @@ _Alarm = Alarm
 
 class Metric(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)[Show boto3-stubs documentation](./service_resource.md#metric)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metric)
     """
 
     metric_name: str
@@ -287,33 +291,35 @@ class Metric(Boto3ServiceResource):
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#metricget_available_subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_available_subresources-method)
         """
 
     def get_statistics(
         self,
+        *,
         StartTime: datetime,
         EndTime: datetime,
         Period: int,
         Dimensions: List["DimensionTypeDef"] = None,
         Statistics: List[StatisticType] = None,
         ExtendedStatistics: List[str] = None,
-        Unit: StandardUnitType = None,
+        Unit: StandardUnitType = None
     ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
-        [Show boto3-stubs documentation](./service_resource.md#metricget_statisticsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_statistics-method)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.load)
-        [Show boto3-stubs documentation](./service_resource.md#metricloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricload-method)
         """
 
     def put_alarm(
         self,
+        *,
         AlarmName: str,
         EvaluationPeriods: int,
         ComparisonOperator: ComparisonOperatorType,
@@ -333,23 +339,23 @@ class Metric(Boto3ServiceResource):
         EvaluateLowSampleCountPercentile: str = None,
         Metrics: List["MetricDataQueryTypeDef"] = None,
         Tags: List["TagTypeDef"] = None,
-        ThresholdMetricId: str = None,
+        ThresholdMetricId: str = None
     ) -> _Alarm:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
-        [Show boto3-stubs documentation](./service_resource.md#metricput_alarmmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_alarm-method)
         """
 
     def put_data(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
-        [Show boto3-stubs documentation](./service_resource.md#metricput_datamethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_data-method)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
-        [Show boto3-stubs documentation](./service_resource.md#metricreloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricreload-method)
         """
 
 
@@ -358,7 +364,7 @@ _Metric = Metric
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource)[Show boto3-stubs documentation](./service_resource.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
     """
 
     alarms: ServiceResourceAlarmsCollection
@@ -366,18 +372,18 @@ class CloudWatchServiceResource(Boto3ServiceResource):
 
     def Alarm(self, name: str) -> _Alarm:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
-        [Show boto3-stubs documentation](./service_resource.md#cloudwatchserviceresourcealarmmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcealarm-method)
         """
 
     def Metric(self, namespace: str, name: str) -> _Metric:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
-        [Show boto3-stubs documentation](./service_resource.md#cloudwatchserviceresourcemetricmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcemetric-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#cloudwatchserviceresourceget_available_subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourceget_available_subresources-method)
         """
