@@ -1,7 +1,7 @@
 """
 Type annotations for cloudwatch service client waiters.
 
-[Open documentation](./waiters.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html)
 
 Usage::
 
@@ -32,11 +32,12 @@ __all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")
 
 class AlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Waiter.alarm_exists)[Show boto3-stubs documentation](./waiters.md#alarmexistswaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Waiter.alarm_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
     """
 
     def wait(
         self,
+        *,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
         AlarmTypes: List[AlarmTypeType] = None,
@@ -46,21 +47,22 @@ class AlarmExistsWaiter(Boto3Waiter):
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExistsWaiter)
-        [Show boto3-stubs documentation](./waiters.md#alarmexists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExistsWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexists)
         """
 
 
 class CompositeAlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Waiter.composite_alarm_exists)[Show boto3-stubs documentation](./waiters.md#compositealarmexistswaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Waiter.composite_alarm_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
     """
 
     def wait(
         self,
+        *,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
         AlarmTypes: List[AlarmTypeType] = None,
@@ -70,9 +72,9 @@ class CompositeAlarmExistsWaiter(Boto3Waiter):
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExistsWaiter)
-        [Show boto3-stubs documentation](./waiters.md#compositealarmexists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExistsWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexists)
         """
